@@ -8,7 +8,8 @@
 
 use super::Session;
 use crate::client::connections::messaging::NUM_OF_ELDERS_SUBSET_FOR_QUERIES;
-use crate::client::{connections::messaging::send_message, Error};
+use crate::client::{connections::messaging::send_message, Error, Result};
+use crate::elder_count;
 use crate::messaging::data::DataCmd;
 use crate::messaging::{
     data::{CmdError, ServiceMsg},
@@ -49,17 +50,27 @@ impl Session {
                     Ok(msg) => match Self::handle_msg(msg, src, session.clone()).await {
                         Ok(()) => {},
                         Err(err) => {
-                            error!("Error while processing incoming message: {:?}. Listening for next message...", err);
+                            error!("Error while handling incoming message: {:?}. Listening for next message...", err);
                         }
                     },
-                    Err(Error::Generic(_)) => {
-                        // TODO: FIX error type
-                        info!("IncomingMessages listener has closed.");
-                        break;
-                    }
-                    Err(err) => {
-                        error!("Error while getting incoming message: {:?}. Listening for next message...", err);
+                    Err(error) => {
+                        match error {
+                            Error::IncomingMessages => {
+                                info!("IncomingMessages listener has closed.");
+                                break;
+                            }
+                            Error::QuicP2p(qp2p_err) => {
+                                  // TODO: Can we recover here?
+                                  info!("Error from Qp2p received, closing listener loop. {:?}", qp2p_err);
+                                  break;
+                            },
+                            error => {
+                                error!("Error while processing incoming message: {:?}. Listening for next message...", error);
+
+                            }
+                        }
                     }
+
                 }
             }
 
@@ -79,7 +90,7 @@ impl Session {
 
             Ok(msg_type)
         } else {
-            Err(Error::Generic("Nothing..".to_string())) // TODO: FIX error type
+            Err(Error::IncomingMessages)
         }
     }
 
@@ -98,6 +109,7 @@ impl Session {
                     SystemMsg::AntiEntropyRedirect {
                         section_auth,
                         section_signed,
+                        section_chain,
                         bounced_msg,
                     },
                 ..
@@ -106,6 +118,7 @@ impl Session {
                     session,
                     section_auth.into_state(),
                     section_signed,
+                    section_chain,
                     bounced_msg,
                     src,
                 )
@@ -218,70 +231,48 @@ impl Session {
     #[instrument(skip_all, level = "debug")]
     async fn handle_ae_redirect_msg(
         session: Session,
-        target_section_auth: SectionAuthorityProvider,
+        target_sap: SectionAuthorityProvider,
         section_signed: KeyedSig,
+        section_chain: SecuredLinkedList,
         bounced_msg: Bytes,
         sender: SocketAddr,
     ) -> Result<(), Error> {
-        // Check if SAP signature is valid
-        if !bincode::serialize(&target_section_auth)
-            .map(|bytes| section_signed.verify(&bytes))
-            .unwrap_or(false)
-        {
-            warn!(
-                "Signature returned with SAP in AE-Redirect response is invalid: {:?}",
-                target_section_auth
-            );
-            return Ok(());
-        }
-
         debug!(
             "Received AE-Redirect for from {}, with SAP: {:?}",
-            sender, target_section_auth
+            sender, target_sap
         );
 
-        if let Some((msg_id, elders, service_msg, mut dst_location, auth)) =
-            Self::new_elder_targets_if_any(
-                session.clone(),
-                bounced_msg.clone(),
-                Some(&target_section_auth),
-            )
-            .await?
+        // Try to update our network knowledge first
+        Self::update_network_knowledge(
+            &session,
+            target_sap.clone(),
+            section_signed,
+            section_chain,
+            sender,
+        )
+        .await;
+
+        if let Some((msg_id, elders, service_msg, dst_location, auth)) =
+            Self::new_elder_targets_if_any(session.clone(), bounced_msg.clone(), Some(&target_sap))
+                .await?
         {
             if elders.is_empty() {
                 debug!("We have already resent this message on an AE-Redirect response. Dropping this instance");
                 return Ok(());
             }
 
-            let message = WireMsg::serialize_msg_payload(&service_msg)?;
-
-            // We cannot trust these Elders belong to the network we are intended to connect to (based on the genesis key we know).
-            // Here we purposefully try and use the genesis key trigger an AE-Retry and expand our network knowledge.
-
-            // TODO: can we attempt to verify the key against out knowledge? (was it signed by a key we know?)
-            let section_pk = session.genesis_key;
-            debug!("Genesis PK we'll be sending is: {:?}", section_pk);
-
-            dst_location.set_section_pk(section_pk);
-
-            // Let's rebuild the message with the updated destination details
+            let payload = WireMsg::serialize_msg_payload(&service_msg)?;
             let wire_msg = WireMsg::new_msg(
                 msg_id,
-                message,
+                payload,
                 MsgKind::ServiceMsg(auth.into_inner()),
                 dst_location,
             )?;
 
             debug!("Resending original message on AE-Redirect with updated details. Expecting an AE-Retry next");
 
-            send_message(
-                session.clone(),
-                elders.clone(),
-                wire_msg,
-                session.endpoint.clone(),
-                msg_id,
-            )
-            .await?;
+            let endpoint = session.endpoint.clone();
+            send_message(session, elders.clone(), wire_msg, endpoint, msg_id).await?;
         }
 
         Ok(())
@@ -291,57 +282,15 @@ impl Session {
     #[instrument(skip_all, level = "debug")]
     async fn handle_ae_retry_msg(
         session: Session,
-        section_auth: SectionAuthorityProvider,
+        sap: SectionAuthorityProvider,
         section_signed: KeyedSig,
         bounced_msg: Bytes,
         proof_chain: SecuredLinkedList,
-        src: SocketAddr,
+        sender: SocketAddr,
     ) -> Result<(), Error> {
-        // Update our network knowledge making sure proof chain
-        // validates the new SAP based on currently known remote section SAP.
-        match session.network.update(
-            SectionAuth {
-                value: section_auth.clone(),
-                sig: section_signed,
-            },
-            &proof_chain,
-        ) {
-            Ok(updated) => {
-                if updated {
-                    debug!(
-                        "Anti-Entropy: updated remote section SAP updated for {:?}",
-                        section_auth.prefix()
-                    );
-                    // Update the PrefixMap on disk
-                    if let Err(e) =
-                        write_data_to_disk(&session.network, &session.root_dir.join("prefix_map"))
-                            .await
-                    {
-                        error!(
-                            "Error writing freshly updated PrefixMap to client dir: {:?}",
-                            e
-                        );
-                    }
-                } else {
-                    debug!(
-                            "Anti-Entropy: discarded SAP for {:?} since it's the same as the one in our records: {:?}",
-                            section_auth.prefix(), section_auth
-                        );
-                }
-            }
-            Err(err) => {
-                warn!(
-                    "Anti-Entropy: failed to update remote section SAP w/ err: {:?}",
-                    err
-                );
-                warn!(
-                    "Anti-Entropy: bounced msg dropped. Failed section auth was {:?} sent by: {:?}",
-                    section_auth.section_key(),
-                    src
-                );
-                return Ok(());
-            }
-        }
+        // Try to update our network knowledge first
+        Self::update_network_knowledge(&session, sap.clone(), section_signed, proof_chain, sender)
+            .await;
 
         // Extract necessary information for resending
         if let Some((msg_id, elders, service_msg, dst_location, auth)) =
@@ -357,7 +306,7 @@ impl Session {
                 }
             }
 
-            debug!("Received AE-Retry with new SAP: {:?}", section_auth);
+            debug!("Received AE-Retry with new SAP: {:?}", sap);
 
             if elders.is_empty() {
                 debug!("We have already responded to this message on an AE-Retry response. Dropping this instance");
@@ -365,7 +314,6 @@ impl Session {
             }
 
             let payload = WireMsg::serialize_msg_payload(&service_msg)?;
-
             let wire_msg = WireMsg::new_msg(
                 msg_id,
                 payload,
@@ -382,7 +330,59 @@ impl Session {
         Ok(())
     }
 
-    /// Checks AE cache to see if we should be forwarding this message (and to whom) or if it has already been dealt with
+    /// Update our network knowledge making sure proof chain validates the
+    /// new SAP based on currently known remote section SAP or genesis key.
+    async fn update_network_knowledge(
+        session: &Session,
+        sap: SectionAuthorityProvider,
+        section_signed: KeyedSig,
+        proof_chain: SecuredLinkedList,
+        sender: SocketAddr,
+    ) {
+        match session.network.update(
+            SectionAuth {
+                value: sap.clone(),
+                sig: section_signed,
+            },
+            &proof_chain,
+        ) {
+            Ok(true) => {
+                debug!(
+                    "Anti-Entropy: updated remote section SAP updated for {:?}",
+                    sap.prefix()
+                );
+                // Update the PrefixMap on disk
+                if let Err(e) =
+                    write_data_to_disk(&session.network, &session.root_dir.join("prefix_map")).await
+                {
+                    error!(
+                        "Error writing freshly updated PrefixMap to client dir: {:?}",
+                        e
+                    );
+                }
+            }
+            Ok(false) => {
+                debug!(
+                    "Anti-Entropy: discarded SAP for {:?} since it's the same as the one in our records: {:?}",
+                    sap.prefix(), sap
+                );
+            }
+            Err(err) => {
+                warn!(
+                    "Anti-Entropy: failed to update remote section SAP w/ err: {:?}",
+                    err
+                );
+                warn!(
+                    "Anti-Entropy: bounced msg dropped. Failed section auth was {:?} sent by: {:?}",
+                    sap.section_key(),
+                    sender
+                );
+            }
+        }
+    }
+
+    /// Checks AE cache to see if we should be forwarding this message (and to whom)
+    /// or if it has already been dealt with
     #[instrument(skip_all, level = "debug")]
     async fn new_elder_targets_if_any(
         session: Session,
@@ -422,11 +422,13 @@ impl Session {
             service_msg
         );
 
-        let (mut target_count, dst_address_of_bounced_msg) = match service_msg.clone() {
+        let (target_count, dst_address_of_bounced_msg) = match service_msg.clone() {
             ServiceMsg::Cmd(cmd) => {
+                let chunk_count = (elder_count() / 3) + 1;
+
                 match &cmd {
-                    DataCmd::StoreChunk(_) => (3, cmd.dst_name()), // stored at Adults, so only 1 correctly functioning Elder need to relay
-                    DataCmd::Register(_) => (7, cmd.dst_name()), // only stored at Elders, all need a copy
+                    DataCmd::StoreChunk(_) => (chunk_count, cmd.dst_name()), // stored at Adults, so only 1 correctly functioning Elder need to relay
+                    DataCmd::Register(_) => (elder_count(), cmd.dst_name()), // only stored at Elders, all need a copy
                 }
             }
             ServiceMsg::Query(query) => (NUM_OF_ELDERS_SUBSET_FOR_QUERIES, query.dst_name()),
@@ -441,25 +443,17 @@ impl Session {
             }
         };
 
-        // In case of redirects, we can send the message to only 3 Elders as anyhow we will get back
-        // an AE-Retry for this message consecutively.
-        if !is_retry {
-            target_count = 3;
-        }
-
         let target_public_key;
 
         // We normally have received auth when we're in AE-Redirect (where we could not trust enough to update our prefixmap)
         let mut target_elders: Vec<_> = if let Some(auth) = received_auth {
             target_public_key = auth.section_key();
             auth.elders()
-                .iter()
-                .sorted_by(|(lhs_name, _), (rhs_name, _)| {
-                    dst_address_of_bounced_msg.cmp_distance(lhs_name, rhs_name)
+                .sorted_by(|lhs, rhs| {
+                    dst_address_of_bounced_msg.cmp_distance(&lhs.name(), &rhs.name())
                 })
-                .map(|(_, addr)| addr)
+                .map(|elder| elder.addr())
                 .take(target_count)
-                .copied()
                 .collect()
         } else {
             // we use whatever is our latest knowledge at this point
@@ -470,7 +464,10 @@ impl Session {
             {
                 target_public_key = sap.section_key();
 
-                sap.elders().values().copied().take(target_count).collect()
+                sap.elders()
+                    .map(|elder| elder.addr())
+                    .take(target_count)
+                    .collect()
             } else {
                 error!("Cannot resend {:?}, no 'received auth' provided, and nothing relevant in session network prefixmap", msg_id);
                 return Ok(None);
