@@ -100,13 +100,14 @@ impl Session {
         // Get DataSection elders details.
         let (elders, section_pk) =
             if let Some(sap) = self.network.closest_or_opposite(&dst_address, None) {
-                let sap_elders = sap.elders().values().copied();
+                let sap_elders: Vec<_> = sap
+                    .elders()
+                    .map(|elder| elder.addr())
+                    .take(targets_count)
+                    .collect();
 
                 trace!("{:?} SAP elders found", sap_elders);
-                (
-                    sap_elders.take(targets_count).collect::<Vec<SocketAddr>>(),
-                    sap.section_key(),
-                )
+                (sap_elders, sap.section_key())
             } else {
                 return Err(Error::NoNetworkKnowledge);
             };
@@ -173,17 +174,17 @@ impl Session {
         let dst = query.dst_name();
 
         // Get DataSection elders details. Resort to own section if DataSection is not available.
-        let (section_pk, elders) = if let Some(sap) = self.network.closest_or_opposite(&dst, None) {
-            (sap.section_key(), sap.value.elders().clone())
+        let sap = self.network.closest_or_opposite(&dst, None);
+        let (section_pk, elders) = if let Some(sap) = &sap {
+            (sap.section_key(), sap.elders())
         } else {
             return Err(Error::NoNetworkKnowledge);
         };
 
         // We select the NUM_OF_ELDERS_SUBSET_FOR_QUERIES closest Elders we are querying
         let chosen_elders: Vec<_> = elders
-            .into_iter()
-            .sorted_by(|(lhs_name, _), (rhs_name, _)| dst.cmp_distance(lhs_name, rhs_name))
-            .map(|(_, addr)| addr)
+            .sorted_by(|lhs, rhs| dst.cmp_distance(&lhs.name(), &rhs.name()))
+            .map(|elder| elder.addr())
             .take(NUM_OF_ELDERS_SUBSET_FOR_QUERIES)
             .collect();
 
@@ -226,7 +227,7 @@ impl Session {
             warn!("No op_id found for query");
         }
 
-        let discarded_responses = std::sync::Arc::new(tokio::sync::Mutex::new(0_usize));
+        let failed_sends = std::sync::Arc::new(tokio::sync::Mutex::new(0_usize));
 
         let dst_location = DstLocation::Section {
             name: dst,
@@ -241,7 +242,7 @@ impl Session {
         for socket in chosen_elders.clone() {
             let endpoint = endpoint.clone();
             let msg_bytes = msg_bytes.clone();
-            let counter_clone = discarded_responses.clone();
+            let counter_clone = failed_sends.clone();
 
             let task_handle = tokio::spawn({
                 let session = self.clone();
@@ -257,6 +258,7 @@ impl Session {
                                 connection.remote_address(),
                                 connection_incoming,
                             );
+
                             connection.send_with(msg_bytes, priority, None).await
                         })
                         .await;
@@ -298,6 +300,16 @@ impl Session {
             }
         }
 
+        let send_failures = *failed_sends.lock().await;
+        if send_failures >= 2 {
+            let successful_connections = 3 - send_failures;
+            error!("Could not send query to enough elders");
+            return Err(Error::InsufficientElderConnections(
+                successful_connections,
+                3,
+            ));
+        }
+
         let response = loop {
             let mut error_response = None;
             match (receiver.recv().await, chunk_addr) {
@@ -387,9 +399,8 @@ impl Session {
             if let Some(sap) = self.network.closest_or_opposite(&dst_address, None) {
                 let mut nodes: Vec<_> = sap
                     .elders()
-                    .values()
+                    .map(|elder| elder.addr())
                     .take(NUM_OF_ELDERS_SUBSET_FOR_QUERIES)
-                    .copied()
                     .collect();
 
                 nodes.shuffle(&mut OsRng);
@@ -574,7 +585,16 @@ pub(super) async fn send_message(
         );
     }
 
-    Ok(())
+    let successful_sends = *successes.read().await;
+    if failures > successful_sends {
+        error!("More send errors than success on send_message");
+        Err(Error::InsufficientElderConnections(
+            elders.len(),
+            successful_sends,
+        ))
+    } else {
+        Ok(())
+    }
 }
 
 #[instrument(skip_all, level = "trace")]
