@@ -18,15 +18,17 @@ use crate::prefix_map::NetworkPrefixMap;
 use crate::types::PublicKey;
 use bls::PublicKey as BlsPublicKey;
 use bytes::Bytes;
+pub(crate) use messaging::SAFE_CLIENT_DIR;
 use qp2p::Endpoint;
+use std::path::PathBuf;
 use std::{collections::HashMap, net::SocketAddr, sync::Arc};
 use tokio::sync::{mpsc::Sender, RwLock};
-use xor_name::XorName;
-type QueryResponseSender = Sender<QueryResponse>;
-type PendingQueryResponses = Arc<RwLock<HashMap<OperationId, QueryResponseSender>>>;
 use tokio::time::Duration;
 use uluru::LRUCache;
 
+type QueryResponseSender = Sender<QueryResponse>;
+type PendingQueryResponses = Arc<RwLock<HashMap<OperationId, QueryResponseSender>>>;
+
 #[derive(Debug)]
 pub(crate) struct QueryResult {
     pub(super) response: QueryResponse,
@@ -41,7 +43,7 @@ pub(super) struct Session {
     // PublicKey of the client
     client_pk: PublicKey,
     // Session endpoint.
-    endpoint: Endpoint<XorName>,
+    endpoint: Endpoint,
     // Channels for sending responses to upper layers
     pending_queries: PendingQueryResponses,
     // Channels for sending errors to upper layer
@@ -60,4 +62,6 @@ pub(super) struct Session {
     initial_connection_check_msg_id: Arc<RwLock<Option<MessageId>>>,
     /// Standard time to await potential AE messages:
     standard_wait: Duration,
+    /// Root storage dir for this session
+    root_dir: PathBuf,
 }
