@@ -36,6 +36,8 @@ use tokio::{sync::mpsc, time::Duration};
 use tracing::Instrument;
 use xor_name::Prefix;
 
+const JOIN_SHARE_EXPIRATION_DURATION: Duration = Duration::from_secs(300);
+
 /// Join the network as new node.
 ///
 /// NOTE: It's not guaranteed this function ever returns. This can happen due to messages being
@@ -74,6 +76,7 @@ struct Join<'a> {
     signature_aggregator: SignatureAggregator,
     node_state_serialized: Option<Vec<u8>>,
     backoff: ExponentialBackoff,
+    aggregation_errors: usize,
 }
 
 impl<'a> Join<'a> {
@@ -89,7 +92,9 @@ impl<'a> Join<'a> {
             node,
             prefix: Prefix::default(),
             prefix_map,
-            signature_aggregator: SignatureAggregator::new(),
+            signature_aggregator: SignatureAggregator::with_expiration(
+                JOIN_SHARE_EXPIRATION_DURATION,
+            ),
             node_state_serialized: None,
             backoff: ExponentialBackoff {
                 initial_interval: Duration::from_millis(50),
@@ -97,6 +102,7 @@ impl<'a> Join<'a> {
                 max_elapsed_time: Some(Duration::from_secs(60)),
                 ..Default::default()
             },
+            aggregation_errors: 0,
         }
     }
 
@@ -223,6 +229,26 @@ impl<'a> Join<'a> {
                             node_state_serialized
                         };
 
+                    let sig_pk = sig_share.public_key_set.public_key();
+
+                    if sig_pk != section_key {
+                        info!(
+                            "ApprovalShare from {} has the wrong signing section key (expected: {:?}, actual: {:?}), retrying",
+                            sender,
+                            section_key,
+                            sig_share.public_key_set.public_key()
+                        );
+
+                        let join_request = JoinRequest {
+                            section_key,
+                            resource_proof_response: None,
+                            aggregated: None,
+                        };
+                        self.send_join_requests(join_request, &[sender], section_key, true)
+                            .await?;
+                        continue;
+                    }
+
                     info!("Aggregating received ApprovalShare from {:?}", sender);
                     match self
                         .signature_aggregator
@@ -258,7 +284,38 @@ impl<'a> Join<'a> {
                             continue;
                         }
                         Err(AggregatorError::NotEnoughShares) => continue,
-                        _ => return Err(Error::InvalidSignatureShare),
+                        error => {
+                            warn!(
+                                "Error received as part of signature aggregation during join: {:?}",
+                                error
+                            );
+                            self.aggregation_errors += 1;
+
+                            // if we've have aggregation errors, we should start fresh as there's likely been a key change
+                            if self.aggregation_errors >= recipients.len() / 2 {
+                                let join_request = JoinRequest {
+                                    section_key,
+                                    resource_proof_response: None,
+                                    aggregated: None,
+                                };
+
+                                // reset aggregation
+                                self.aggregation_errors = 0;
+                                self.signature_aggregator = SignatureAggregator::with_expiration(
+                                    JOIN_SHARE_EXPIRATION_DURATION,
+                                );
+
+                                self.send_join_requests(
+                                    join_request,
+                                    &recipients,
+                                    section_key,
+                                    true,
+                                )
+                                .await?;
+                            }
+
+                            continue;
+                        }
                     }
                 }
                 JoinResponse::Retry {
