@@ -103,8 +103,6 @@ pub(crate) struct Core {
     dkg_sessions: Arc<RwLock<HashMap<DkgSessionId, DkgSessionInfo>>>,
     // Voter for Dkg
     dkg_voter: DkgVoter,
-    // Boolean to represent ongoing DKG
-    is_dkg_underway: Arc<RwLock<bool>>,
     relocate_state: Arc<RwLock<Option<RelocateState>>>,
     pub(super) event_tx: mpsc::Sender<Event>,
     joins_allowed: Arc<RwLock<bool>>,
@@ -154,7 +152,6 @@ impl Core {
             split_barrier: Arc::new(RwLock::new(SplitBarrier::new())),
             message_aggregator: SignatureAggregator::default(),
             dkg_voter: DkgVoter::default(),
-            is_dkg_underway: Arc::new(RwLock::new(false)),
             relocate_state: Arc::new(RwLock::new(None)),
             event_tx,
             joins_allowed: Arc::new(RwLock::new(true)),
