@@ -265,15 +265,7 @@ impl Core {
 
             info!("New SAP agreed for {:?}: {:?}", prefix, signed_sap);
 
-            // If we have the key share for new SAP key we can switch to this new SAP
-            let switch_to_new_sap = (self.is_not_elder().await
-                && !signed_sap.contains_elder(&self.node.read().await.name()))
-                || self
-                    .section_keys_provider
-                    .key_share(&signed_sap.section_key())
-                    .await
-                    .is_ok();
-            trace!("switch_to_new_sap {:?}", switch_to_new_sap);
+            let our_name = self.node.read().await.name();
 
             // Let's update our network knowledge, including our
             // section SAP and chain if the new SAP's prefix matches our name
@@ -288,11 +280,11 @@ impl Core {
                 Ok(()) => match self
                     .network_knowledge
                     .update_knowledge_if_valid(
-                        signed_sap,
+                        signed_sap.clone(),
                         &proof_chain,
                         None,
-                        &self.node.read().await.name(),
-                        switch_to_new_sap,
+                        &our_name,
+                        &self.section_keys_provider,
                     )
                     .await
                 {
@@ -302,6 +294,7 @@ impl Core {
                     ),
                     Ok(true) => {
                         info!("Updated our network knowledge for {:?}", prefix);
+
                         self.write_prefix_map().await
                     }
                     _ => {}
@@ -309,8 +302,6 @@ impl Core {
             }
         }
 
-        *self.is_dkg_underway.write().await = false;
-
         info!(
             "Prefixes we know about: {:?}",
             self.network_knowledge.prefix_map()
