@@ -38,29 +38,20 @@ impl Core {
     ) -> Result<Vec<Command>> {
         let snapshot = self.state_snapshot().await;
 
-        // If we have the key share for new SAP key we can switch to this new SAP.
-        // Otherwise, only update when not being the elder of new SAP.
-        let switch_to_new_sap = (self.is_not_elder().await
-            && !section_auth.contains_elder(&self.node.read().await.name()))
-            || self
-                .section_keys_provider
-                .key_share(&section_signed.public_key)
-                .await
-                .is_ok();
-
+        let our_name = self.node.read().await.name();
         let signed_sap = SectionAuth {
             value: section_auth.clone(),
-            sig: section_signed,
+            sig: section_signed.clone(),
         };
 
         let _updated = self
             .network_knowledge
             .update_knowledge_if_valid(
-                signed_sap,
+                signed_sap.clone(),
                 &proof_chain,
                 members,
-                &self.node.read().await.name(),
-                switch_to_new_sap,
+                &our_name,
+                &self.section_keys_provider,
             )
             .await?;
 
@@ -212,32 +203,23 @@ impl Core {
 
         info!("Anti-Entropy: message received from peer: {}", sender);
 
-        // If we have the key share for new SAP key we can switch to this new SAP.
-        // Otherwise, only update when not being the elder of new SAP.
-        let switch_to_new_sap = (self.is_not_elder().await
-            && !section_auth.contains_elder(&self.node.read().await.name()))
-            || self
-                .section_keys_provider
-                .key_share(&section_signed.public_key)
-                .await
-                .is_ok();
-
         let prefix = section_auth.prefix();
         let dst_section_key = section_auth.section_key();
         let signed_sap = SectionAuth {
             value: section_auth.clone(),
-            sig: section_signed,
+            sig: section_signed.clone(),
         };
+        let our_name = self.node.read().await.name();
 
         // Update our network knowledge.
         if self
             .network_knowledge
             .update_knowledge_if_valid(
-                signed_sap,
+                signed_sap.clone(),
                 &proof_chain,
                 None,
-                &self.node.read().await.name(),
-                switch_to_new_sap,
+                &our_name,
+                &self.section_keys_provider,
             )
             .await?
         {
@@ -468,10 +450,13 @@ mod tests {
         create_test_used_space_and_root_storage,
         dkg::test_utils::section_signed,
         ed25519,
-        network_knowledge::test_utils::{gen_addr, gen_section_authority_provider},
+        network_knowledge::{
+            test_utils::{gen_addr, gen_section_authority_provider},
+            SectionKeysProvider,
+        },
         node::Node,
         routing_api::tests::create_comm,
-        XorName, MIN_ADULT_AGE,
+        SectionKeyShare, XorName, MIN_ADULT_AGE,
     };
 
     use assert_matches::assert_matches;
@@ -556,7 +541,7 @@ mod tests {
                     &env.proof_chain,
                     None,
                     &env.core.node.read().await.name(),
-                    false,
+                    &env.core.section_keys_provider
                 )
                 .await?
         );
@@ -698,7 +683,7 @@ mod tests {
             assert_eq!(genesis_pk, *chain.root_key());
 
             let (used_space, root_storage_dir) = create_test_used_space_and_root_storage()?;
-            let core = Core::first_node(
+            let mut core = Core::first_node(
                 create_comm().await?,
                 node.clone(),
                 mpsc::channel(1).0,
@@ -709,11 +694,24 @@ mod tests {
             .await?;
 
             let genesis_sap = core.network_knowledge().authority_provider().await;
+            let section_key_share = SectionKeyShare {
+                public_key_set: secret_key_set.public_keys(),
+                index: 0,
+                secret_key_share: secret_key_set.secret_key_share(0),
+            };
+
+            core.section_keys_provider = SectionKeysProvider::new(Some(section_key_share)).await;
 
             // get our Core to now be in prefix(0)
             let _ = core
                 .network_knowledge()
-                .update_knowledge_if_valid(signed_sap, &chain, None, &node.name(), true)
+                .update_knowledge_if_valid(
+                    signed_sap.clone(),
+                    &chain,
+                    None,
+                    &node.name(),
+                    &core.section_keys_provider,
+                )
                 .await;
 
             // generate other SAP for prefix1
