@@ -7,16 +7,17 @@
 // permissions and limitations relating to use of the SAFE Network Software.
 
 use super::Core;
+use crate::elder_count;
 use crate::messaging::{
-    system::{Proposal, RelocateDetails, RelocatePromise, SystemMsg},
+    system::{RelocateDetails, RelocatePromise, SystemMsg},
     AuthorityProof, SectionAuth,
 };
 use crate::routing::{
-    core::bootstrap::JoiningAsRelocated,
+    core::{bootstrap::JoiningAsRelocated, Proposal},
     error::Result,
     relocation::{self, RelocateAction, RelocateDetailsUtils, RelocateState},
     routing_api::command::Command,
-    Event, Peer, ELDER_SIZE,
+    Event, Peer,
 };
 use xor_name::XorName;
 
@@ -35,7 +36,7 @@ impl Core {
             .authority_provider()
             .await
             .elder_count()
-            < ELDER_SIZE
+            < elder_count()
         {
             return Ok(commands);
         }
@@ -54,7 +55,7 @@ impl Core {
                 continue;
             }
 
-            let peer = info.to_peer();
+            let peer = info.peer().clone();
 
             debug!(
                 "Relocating {:?} to {} (on churn of {})",
@@ -64,7 +65,7 @@ impl Core {
             );
 
             commands.extend(
-                self.propose(Proposal::Offline(info.relocate(*action.dst()).into_msg()))
+                self.propose(Proposal::Offline(info.relocate(*action.dst())))
                     .await?,
             );
 
@@ -215,9 +216,9 @@ impl Core {
         }
 
         if let Some(info) = self.network_knowledge.members().get(&promise.name) {
-            let peer = info.to_peer();
-            let details = RelocateDetails::new(&self.network_knowledge, &peer, promise.dst).await;
-            commands.extend(self.send_relocate(peer, details).await?);
+            let peer = info.peer();
+            let details = RelocateDetails::new(&self.network_knowledge, peer, promise.dst).await;
+            commands.extend(self.send_relocate(peer.clone(), details).await?);
         } else {
             error!(
                 "ignore returned RelocatePromise from {} - unknown node",
