@@ -6,11 +6,10 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
-use crate::messaging::system::{DkgFailureSig, DkgFailureSigSet, DkgSessionId, ElderCandidates};
+use crate::messaging::system::{DkgFailureSig, DkgFailureSigSet, DkgSessionId};
 use crate::routing::{
     ed25519::{self, Digest256, Keypair, Verifier},
-    peer::PeerUtils,
-    section::ElderCandidatesUtils,
+    network_knowledge::ElderCandidates,
     supermajority,
 };
 use std::collections::BTreeSet;
@@ -27,12 +26,12 @@ impl DkgSessionIdUtils for DkgSessionId {
         let mut hasher = Sha3::v256();
         let mut hash = Digest256::default();
 
-        for peer in elder_candidates.peers() {
-            hasher.update(&peer.name().0);
+        for peer in elder_candidates.names() {
+            hasher.update(&peer.0);
         }
 
-        hasher.update(&elder_candidates.prefix.name().0);
-        hasher.update(&elder_candidates.prefix.bit_count().to_le_bytes());
+        hasher.update(&elder_candidates.prefix().name().0);
+        hasher.update(&elder_candidates.prefix().bit_count().to_le_bytes());
         hasher.finalize(&mut hash);
 
         Self { hash, generation }
@@ -97,7 +96,7 @@ impl DkgFailureSigSetUtils for DkgFailureSigSet {
     // Check whether we have enough signatures to reach agreement on the failure. The contained signatures
     // are assumed valid.
     fn has_agreement(&self, elder_candidates: &ElderCandidates) -> bool {
-        has_failure_agreement(elder_candidates.elders.len(), self.sigs.len())
+        has_failure_agreement(elder_candidates.len(), self.sigs.len())
     }
 
     fn verify(&self, elder_candidates: &ElderCandidates, generation: u64) -> bool {
@@ -109,14 +108,12 @@ impl DkgFailureSigSetUtils for DkgFailureSigSet {
             .sigs
             .iter()
             .filter(|sig| {
-                elder_candidates
-                    .elders
-                    .contains_key(&ed25519::name(&sig.public_key))
+                elder_candidates.contains(&ed25519::name(&sig.public_key))
                     && sig.public_key.verify(&hash, &sig.signature).is_ok()
             })
             .count();
 
-        has_failure_agreement(elder_candidates.elders.len(), votes)
+        has_failure_agreement(elder_candidates.len(), votes)
     }
 }
 
