@@ -264,7 +264,7 @@ impl NetworkKnowledge {
         proof_chain: &SecuredLinkedList,
         updated_members: Option<SectionPeers>,
         our_name: &XorName,
-        update_sap: bool,
+        section_keys_provider: &SectionKeysProvider,
     ) -> Result<bool> {
         let mut there_was_an_update = false;
         let provided_sap = signed_sap.value.clone();
@@ -289,11 +289,22 @@ impl NetworkKnowledge {
                     .await
                     .join(proof_chain.clone())?;
 
+                let switch_to_new_sap = (!self.is_elder(our_name).await
+                    && !provided_sap.contains_elder(our_name))
+                    || section_keys_provider
+                        .key_share(&signed_sap.section_key())
+                        .await
+                        .is_ok();
+                trace!(
+                    "update_knowledge_if_valid switch_to_new_sap {:?}",
+                    switch_to_new_sap
+                );
+
                 // We try to update our SAP and own chain only if we were flagged to,
                 // otherwise this update could be due to an AE message and we still don't have
                 // the key share for the new SAP, making this node unable to sign section messages
                 // and possibly being kicked out of the group of Elders.
-                if update_sap && provided_sap.prefix().matches(our_name) {
+                if switch_to_new_sap && provided_sap.prefix().matches(our_name) {
                     let our_prev_prefix = self.prefix().await;
                     *self.signed_sap.write().await = signed_sap.clone();
                     *self.chain.write().await = self
@@ -334,7 +345,6 @@ impl NetworkKnowledge {
                     self.prefix().await,
                     self.members()
                 );
-                there_was_an_update = true;
             }
         }
 
