@@ -49,11 +49,9 @@ pub(crate) async fn actions(
 
     for node_state in candidates {
         if node_state.age() == max_age {
-            let peer = node_state.to_peer();
-            relocating_nodes.push((
-                node_state,
-                RelocateAction::new(network_knowledge, &peer, churn_name).await,
-            ))
+            let action =
+                RelocateAction::new(network_knowledge, node_state.peer(), churn_name).await;
+            relocating_nodes.push((node_state, action))
         }
     }
 
@@ -244,11 +242,11 @@ fn trailing_zeros(bytes: &[u8]) -> u32 {
 #[cfg(test)]
 mod tests {
     use super::*;
+    use crate::elder_count;
     use crate::routing::{
         dkg::test_utils::section_signed,
         network_knowledge::peer::test_utils::arbitrary_unique_peers,
-        network_knowledge::SectionAuthorityProvider, routing_api::tests::SecretKeySet, ELDER_SIZE,
-        MIN_AGE,
+        network_knowledge::SectionAuthorityProvider, routing_api::tests::SecretKeySet, MIN_AGE,
     };
     use assert_matches::assert_matches;
     use eyre::Result;
@@ -275,7 +273,7 @@ mod tests {
     proptest! {
         #[test]
         fn proptest_actions(
-            peers in arbitrary_unique_peers(2..ELDER_SIZE + 1, MIN_AGE..MAX_AGE),
+            peers in arbitrary_unique_peers(2..elder_count() + 1, MIN_AGE..MAX_AGE),
             signature_trailing_zeros in 0..MAX_AGE,
             seed in any::<u64>().no_shrink())
         {
@@ -294,14 +292,14 @@ mod tests {
         let sk = sk_set.secret_key();
         let genesis_pk = sk.public_key();
 
-        // Create `Section` with `peers` as its members and set the `ELDER_SIZE` oldest peers as
+        // Create `Section` with `peers` as its members and set the `elder_count()` oldest peers as
         // the elders.
         let section_auth = SectionAuthorityProvider::new(
             peers
                 .iter()
                 .sorted_by_key(|peer| peer.age())
                 .rev()
-                .take(ELDER_SIZE)
+                .take(elder_count())
                 .cloned(),
             Prefix::default(),
             sk_set.public_keys(),
@@ -316,7 +314,7 @@ mod tests {
         )?;
 
         for peer in &peers {
-            let info = NodeState::joined(peer, None);
+            let info = NodeState::joined(peer.clone(), None);
             let info = section_signed(sk, info)?;
 
             let res = futures::executor::block_on(network_knowledge.update_member(info));
