@@ -6,8 +6,9 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
+use crate::messaging::system::SectionAuth;
 use crate::messaging::{
-    system::{DkgFailureSigSet, KeyedSig, SystemMsg},
+    system::{DkgFailureSigSet, KeyedSig, NodeState, SystemMsg},
     DstLocation, MessageId, NodeMsgAuthority, WireMsg,
 };
 use crate::routing::{
@@ -57,6 +58,8 @@ pub(crate) enum Command {
     HandlePeerLost(Peer),
     /// Handle agreement on a proposal.
     HandleAgreement { proposal: Proposal, sig: KeyedSig },
+    /// Handle a new Node joining agreement.
+    HandleNewNodeOnline(SectionAuth<NodeState>),
     /// Handle agree on elders. This blocks node message processing until complete.
     HandleElderAgreement { proposal: Proposal, sig: KeyedSig },
     /// Handle the outcome of a DKG session where we are one of the participants (that is, one of
@@ -95,12 +98,10 @@ pub(crate) enum Command {
     /// Attempt to set JoinsAllowed flag.
     SetJoinsAllowed(bool),
     /// Test peer's connectivity
-    ProposeOnline {
+    SendAcceptedOnlineShare {
         peer: Peer,
         // Previous name if relocated.
         previous_name: Option<XorName>,
-        // The key of the destination section that the joining node knows, if any.
-        dst_key: Option<bls::PublicKey>,
     },
     /// Proposes a peer as offline
     ProposeOffline(XorName),
@@ -125,6 +126,7 @@ impl fmt::Display for Command {
             Command::HandlePeerLost(peer) => write!(f, "HandlePeerLost({:?})", peer.name()),
             Command::HandleAgreement { .. } => write!(f, "HandleAgreement"),
             Command::HandleElderAgreement { .. } => write!(f, "HandleElderAgreement"),
+            Command::HandleNewNodeOnline(_) => write!(f, "HandleNewNodeOnline"),
             Command::HandleDkgOutcome { .. } => write!(f, "HandleDkgOutcome"),
             Command::HandleDkgFailure(_) => write!(f, "HandleDkgFailure"),
             #[cfg(not(feature = "unstable-wiremsg-debuginfo"))]
@@ -151,7 +153,7 @@ impl fmt::Display for Command {
                 write!(f, "HandleRelocationComplete")
             }
             Command::SetJoinsAllowed(_) => write!(f, "SetJoinsAllowed"),
-            Command::ProposeOnline { .. } => write!(f, "ProposeOnline"),
+            Command::SendAcceptedOnlineShare { .. } => write!(f, "SendAcceptedOnlineShare"),
             Command::ProposeOffline(_) => write!(f, "ProposeOffline"),
             Command::StartConnectivityTest(_) => write!(f, "StartConnectivityTest"),
             Command::TestConnectivity(_) => write!(f, "TestConnectivity"),
